@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver;
 # ABSTRACT: Neo4j community graph database driver for Bolt and HTTP
-$Neo4j::Driver::VERSION = '0.45'; # TRIAL
+$Neo4j::Driver::VERSION = '1.00'; # TRIAL
 
 use Carp qw(croak);
 
@@ -17,7 +17,6 @@ use Neo4j::Driver::Type::Node;
 use Neo4j::Driver::Type::Relationship;
 use Neo4j::Driver::Type::Path;
 use Neo4j::Driver::Type::Point;
-use Neo4j::Driver::Type::Temporal;
 
 
 my %NEO4J_DEFAULT_PORT = (
@@ -28,15 +27,10 @@ my %NEO4J_DEFAULT_PORT = (
 
 my %OPTIONS = (
 	auth => 'auth',
-	ca_file => 'tls_ca',
-	cypher_filter => 'cypher_filter',
 	cypher_params => 'cypher_params_v2',
-	cypher_types => 'cypher_types',
 	encrypted => 'tls',
-	jolt => 'jolt',
 	concurrent_tx => 'concurrent_tx',
 	max_transaction_retry_time => 'max_transaction_retry_time',
-	net_module => 'net_module',
 	timeout => 'timeout',
 	tls => 'tls',
 	tls_ca => 'tls_ca',
@@ -58,7 +52,7 @@ my %DEFAULTS = (
 sub new {
 	my ($class, $config, @extra) = @_;
 	
-	my $self = bless { config => { %DEFAULTS }, die_on_error => 1 }, $class;
+	my $self = bless { config => { %DEFAULTS } }, $class;
 	$self->{plugins} = Neo4j::Driver::Events->new;
 	
 	croak __PACKAGE__ . "->new() with multiple arguments unsupported" if @extra;
@@ -108,6 +102,8 @@ sub _check_uri {
 sub _fix_neo4j_uri {
 	my ($self) = @_;
 	
+	croak "The concurrent_tx config option may only be used with http:/https: URIs" if $self->{config}->{concurrent_tx};
+	
 	my $uri = $self->{config}->{uri};
 	$uri->scheme( exists $INC{'Neo4j/Bolt.pm'} ? 'bolt' : $self->{config}->{tls} ? 'https' : 'http' );
 	$uri->port( $NEO4J_DEFAULT_PORT{ $uri->scheme } ) if ! $uri->_port;
@@ -117,7 +113,7 @@ sub _fix_neo4j_uri {
 sub basic_auth {
 	my ($self, $username, $password) = @_;
 	
-	warnings::warnif deprecated => "Deprecated sequence: call basic_auth() before session()" if $self->{server_info};
+	croak "Unsupported sequence: call basic_auth() before session()" if $self->{server_info};
 	
 	$self->{config}->{auth} = {
 		scheme => 'basic',
@@ -162,11 +158,6 @@ sub session {
 		warnings::warnif deprecated => sprintf "Internal API %s->{%s} may be unavailable in Neo4j::Driver 1.00", __PACKAGE__, $_ for grep { $self->{$_} } @OPTIONS{ sort keys %OPTIONS };
 	}
 	
-	$self->{plugins}->{die_on_error} = $self->{die_on_error};
-	warnings::warnif deprecated => __PACKAGE__ . "->{die_on_error} is deprecated" unless $self->{die_on_error};
-	warnings::warnif deprecated => __PACKAGE__ . "->{http_timeout} is deprecated; use config()" if defined $self->{http_timeout};
-	$self->{config}->{timeout} //= $self->{http_timeout};
-	
 	@options = %{$options[0]} if @options == 1 && ref $options[0] eq 'HASH';
 	my %options = $self->_parse_options('session', ['database'], @options);
 	
@@ -183,18 +174,9 @@ sub _parse_options {
 	croak "Odd number of elements in $context options hash" if @options & 1;
 	my %options = @options;
 	
-	warnings::warnif deprecated => "Config option ca_file is deprecated; use trust_ca" if $options{ca_file};
-	warnings::warnif deprecated => "Config option cypher_types is deprecated" if $options{cypher_types};
 	if ($options{cypher_params}) {
-		croak "Unimplemented cypher params filter '$options{cypher_params}'" if $options{cypher_params} ne v2;
+		croak "Unimplemented cypher params filter '$options{cypher_params}'" if $options{cypher_params} !~ m<^\x02|v2$>;
 	}
-	elsif ($options{cypher_filter}) {
-		warnings::warnif deprecated => "Config option cypher_filter is deprecated; use cypher_params";
-		croak "Unimplemented cypher filter '$options{cypher_filter}'" if $options{cypher_filter} ne 'params';
-		$options{cypher_params} = v2;
-	}
-	warnings::warnif deprecated => "Config option jolt is deprecated: Jolt is now enabled by default" if defined $options{jolt};
-	warnings::warnif deprecated => "Config option net_module is deprecated; use plug-in interface" if defined $options{net_module};
 	
 	my @unsupported = ();
 	foreach my $key (keys %options) {
@@ -208,20 +190,15 @@ sub _parse_options {
 
 sub plugin {
 	# uncoverable pod (experimental feature)
-	my ($self, $package, @extra) = @_;
+	my ($self, $plugin, @extra) = @_;
 	
 	croak "plugin() with more than one argument is unsupported" if @extra;
-	$self->{plugins}->_register_plugin($package);
+	croak "Unsupported sequence: call plugin() before session()" if $self->{server_info};
+	$self->{plugins}->_register_plugin($plugin);
 	return $self;
 }
 
 
-sub close {
-	# uncoverable pod (see Deprecations.pod)
-	warnings::warnif deprecated => __PACKAGE__ . "->close() is deprecated";
-}
-
-
 
 
 package # private
@@ -232,7 +209,7 @@ use parent 'URI::_server';
 # The server methods need to be available for bolt: URI instances
 # even when the Neo4j-Bolt distribution is not installed.
 
- 
+
 1;
 
 __END__
@@ -247,27 +224,28 @@ Neo4j::Driver - Neo4j community graph database driver for Bolt and HTTP
 
 =head1 VERSION
 
-version 0.45
+version 1.00
 
 =head1 SYNOPSIS
 
- use Neo4j::Driver;
  $uri = 'bolt://localhost';  # requires Neo4j::Bolt
  $uri = 'http://localhost';
- $driver = Neo4j::Driver->new($uri)->basic_auth('neo4j', 'password');
  
- sub say_friends_of ($person) {
-   $query = 'MATCH (a:Person)-[:KNOWS]->(f) '
-             . 'WHERE a.name = $name RETURN f.name';
-   @records = $driver->session->execute_read( sub ($tx) {
-     $tx->run($query, { name => $person })->list;
-   });
-   foreach $record ( @records ) {
-     say $record->get('f.name');
-   }
+ $driver = Neo4j::Driver->new({ uri => $uri, ... });
+ $driver->basic_auth( $user, $password );
+ $session = $driver->session;
+ 
+ $query = <<~END;
+   MATCH (someone :Person)-[:KNOWS]->(friend)
+   WHERE someone.name = \$name
+   RETURN friend.name
+   END
+ @records = $session->execute_read( sub ($tx) {
+   $tx->run($query, { name => 'Alice' })->list;
+ });
+ foreach my $record ( @records ) {
+   say $record->get('friend.name');
  }
- 
- say_friends_of 'Alice';
 
 =head1 DESCRIPTION
 
@@ -280,9 +258,9 @@ This extends the uniformity across languages, which is a
 stated goal of the Neo4j Driver API, to Perl.
 
 This driver targets the Neo4j community edition,
-version 2.x, 3.x, 4.x, and 5.x. The Neo4j enterprise edition
-and AuraDB are only supported as far as practical,
-but patches will be accepted.
+version 2.x, 3.x, 4.x, and 5.x. Other Neo4j editions are
+only supported as far as practical, but patches targeting
+them are welcome.
 
 Two different network protocols exist for connecting to Neo4j.
 By default, Neo4j servers offer both, but this can be changed
@@ -296,8 +274,8 @@ L<"Configure connectors" in the Neo4j Operations Manual|https://neo4j.com/docs/o
 Bolt is a Neo4j proprietary, binary protocol, available with
 S<Neo4j 3.0> and newer. Bolt communication may be encrypted or
 unencrypted. Because Bolt is faster than HTTP, it is generally
-the recommended protocol. However, Perl support for it may be
-lagging after major updates to Neo4j.
+the recommended protocol. However, Perl support for it tends
+to lag behind after major updates to Neo4j.
 
 This driver supports Bolt, but doesn't bundle the necessary XS
 packages. You will need to install L<Neo4j::Bolt> separately
@@ -323,10 +301,6 @@ install L<LWP::Protocol::https> separately to enable HTTPS.
 The protocol is automatically chosen based on the URI scheme.
 See L<Neo4j::Driver::Config/"uri"> for details.
 
-This driver will soon
-move to S<version 1.00,> removing L<deprecated
-functionality|Neo4j::Driver::Deprecations>.
-
 =head1 METHODS
 
 L<Neo4j::Driver> implements the following methods.
@@ -374,11 +348,23 @@ as a hash reference. See L<Neo4j::Driver::Config> for a
 list of supported options. Alternatively, instead of the hash
 reference, the Neo4j server URI may be given as a scalar string.
 
- $driver = Neo4j::Driver->new('http://localhost');
+ $driver = Neo4j::Driver->new('bolt://localhost');
 
 If C<new()> is called with no arguments, a default configuration
 will be used for the driver.
 
+=head2 plugin
+
+ $driver->plugin( $plugin );
+
+Load the given plug-in object into the driver. This method returns
+the modified driver, so that method chaining is possible.
+
+Details on the implementation of plug-ins including descriptions of
+individual event handlers are provided in L<Neo4j::Driver::Plugin>.
+Note that the plug-in API is experimental because some of its parts
+are still evolving.
+
 =head2 session
 
  $session = $driver->session;
@@ -397,92 +383,68 @@ in F<neo4j.conf>.
 The C<database> option is silently ignored when used with Neo4j
 S<versions 2> S<and 3>, which only support a single database.
 
-=head1 EXPERIMENTAL FEATURES
-
-L<Neo4j::Driver> implements the following experimental features.
-These are subject to unannounced modification or removal in future
-versions. Expect your code to break if you depend upon these
-features.
-
-=head2 Plug-in modules
-
- $driver->plugin(  Local::MyPlugin->new );
-
-The driver offers a simple plug-in interface. Plug-ins are modules
-providing handlers for events that may be triggered by the driver.
-Plug-ins are loaded by calling the C<plugin()> method with the
-the blessed instance of a plug-in as parameter.
-
-Details on the implementation of plug-ins including descriptions of
-individual events are provided in L<Neo4j::Driver::Plugin>.
-
-This feature is experimental because some parts of the plug-in
-API are still evolving.
-
-=head1 ENVIRONMENT
-
-This software requires at least Perl 5.10, though you should consider
-using Perl 5.26 or newer if you can.
-
-=head1 DIAGNOSTICS
-
-Neo4j::Driver triggers an "error" event as soon as an error
-condition is discovered. If unhandled, this event will cause
-the driver to die with an error string.
-See L<Neo4j::Driver::Transaction/"ERROR HANDLING"> for
-further information.
-
-Warnings are given when deprecated or ambiguous method calls are used.
-These warnings may be disabled if desired.
-
- no warnings 'deprecated';
- no warnings 'ambiguous';
-
-=head1 BUGS
-
-See the F<TODO> document and Github for known issues and planned
-improvements. Please report new issues and other feedback on Github.
-
-Just like the official Neo4j drivers, this driver has been designed to strike
-a balance between an idiomatic API for Perl and a uniform surface across all
-languages. Differences between this driver and the official Neo4j drivers in
-either the API or the behaviour are generally to be regarded as bugs unless
-there is a compelling reason for a different approach in Perl.
-
 =head1 SEE ALSO
 
+Interacting with a Neo4j database:
+
 =over
 
 =item * L<Neo4j::Driver::B<Session>>
 
 =item * L<Neo4j::Driver::Types>
 
-=item * Official API documentation:
-L<Neo4j Driver API Specification|https://github.com/neo4j/docs-bolt/blob/main/modules/ROOT/pages/driver-api/index.adoc>,
-L<Neo4j Drivers Manual|https://neo4j.com/docs/java-manual/5/>,
-L<Neo4j HTTP API Docs|https://neo4j.com/docs/http-api/5/>
+=back
 
-=item * Other modules for working with Neo4j:
-L<DBD::Neo4p>,
-L<Neo4j::Bolt>,
-L<Neo4j::Cypher::Abstract>,
-L<REST::Cypher>,
-L<REST::Neo4p>
+Official API documentation:
+
+=over
+
+=item * L<Neo4j Driver API Specification|https://github.com/neo4j/docs-bolt/blob/main/modules/ROOT/pages/driver-api/index.adoc>
+
+=item * L<Neo4j Drivers Manual|https://neo4j.com/docs/java-manual/5/>
+
+=item * L<Neo4j HTTP API Docs|https://neo4j.com/docs/http-api/5/>
 
 =back
 
-=head1 ACKNOWLEDGEMENT
+Other Perl modules for working with Neo4j:
 
-Special thanks go to Mark A. Jensen (MAJENSEN). Without the
-inspiration of his L<REST::Neo4p>, this driver project I<probably>
-would never have been even gotten started. And without Mark's
-tremendous work on L<Neo4j::Bolt> and libneo4j-client, this
-driver I<certainly> would be in much worse shape than it is today.
+=over
+
+=item * L<DBD::Neo4p> E<ndash> a L<DBI>-compliant wrapper for REST::Neo4p
+
+=item * L<Neo4j::Bolt> E<ndash> XS bindings for libneo4j-omni, a S<C library> for Bolt
+
+=item * L<Neo4j::Cypher::Abstract> E<ndash> generate Cypher query statements
+
+=item * L<Neo4j::Types::Generic> E<ndash> create values for Bolt query parameters
+
+=item * L<REST::Cypher> E<ndash> access the REST interface in old Neo4j versions
+
+=item * L<REST::Neo4p> E<ndash> object mappings for Neo4j nodes and relationships
+
+=back
 
 =head1 AUTHOR
 
 Arne Johannessen (L<AJNN|https://metacpan.org/author/AJNN>)
 
+=head1 CONTRIBUTORS
+
+=for stopwords Mark A. Jensen Mohammad S Anwar
+
+=over 4
+
+=item *
+
+Mark A. Jensen <majensen@cpan.org>
+
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016-2024 by Arne Johannessen.
