@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Net::HTTP;
 # ABSTRACT: Network controller for Neo4j HTTP
-$Neo4j::Driver::Net::HTTP::VERSION = '0.45'; # TRIAL
+$Neo4j::Driver::Net::HTTP::VERSION = '1.00'; # TRIAL
 
 # This package is not part of the public Neo4j::Driver API.
 
@@ -37,17 +37,17 @@ sub new {
 	my ($class, $driver) = @_;
 	
 	$driver->{plugins}->{default_handlers}->{http_adapter_factory} //= sub {
-		my $net_module = $driver->config('net_module') || 'Neo4j::Driver::Net::HTTP::LWP';
+		my $net_module = $driver->{config}->{net_module} || 'Neo4j::Driver::Net::HTTP::LWP';
 		return $net_module->new($driver);
 	};
 	my $http_adapter = $driver->{plugins}->trigger('http_adapter_factory', $driver);
 	
 	my $self = bless {
 		events => $driver->{plugins},
-		cypher_types => $driver->config('cypher_types'),
+		cypher_types => $driver->{config}->{cypher_types},
 		server_info => $driver->{server_info},
 		http_agent => $http_adapter,
-		want_jolt => $driver->config('jolt'),
+		want_jolt => $driver->{config}->{jolt},
 		want_concurrent => $driver->config('concurrent_tx') // 0,
 		active_tx => {},
 	}, $class;
@@ -119,9 +119,10 @@ sub _set_database {
 sub _run {
 	my ($self, $tx, @statements) = @_;
 	
-	if ( %{$self->{active_tx}} && ! $self->{want_concurrent} ) {
-		my $is_concurrent = ! defined $tx->{commit_endpoint} || keys %{$self->{active_tx}} > 1;
-		$is_concurrent and carp "Concurrent transactions for HTTP are disabled; use multiple sessions or enable the concurrent_tx config option (this warning will be fatal in Neo4j::Driver 1.xx)";
+	if ( ! $self->{want_concurrent} ) {
+		# A new HTTP tx has no commit endpoint until after the first result is received.
+		my $is_concurrent = keys %{$self->{active_tx}} && ! defined $tx->{commit_endpoint};
+		$is_concurrent and croak "Concurrent transactions for HTTP are disabled; use multiple sessions or enable the concurrent_tx config option";
 	}
 	
 	my $json = { statements => \@statements };
