@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Net::HTTP::LWP;
 # ABSTRACT: HTTP network adapter for libwww-perl
-$Neo4j::Driver::Net::HTTP::LWP::VERSION = '0.45'; # TRIAL
+$Neo4j::Driver::Net::HTTP::LWP::VERSION = '1.00'; # TRIAL
 
 use Carp qw(croak);
 our @CARP_NOT = qw(Neo4j::Driver::Net::HTTP);
@@ -63,22 +63,6 @@ sub new {
 }
 
 
-sub protocol {
-	# uncoverable pod (see Deprecations.pod)
-	my ($self) = @_;
-	warnings::warnif deprecated => __PACKAGE__ . "->protocol() is deprecated";
-	return $self->{response}->protocol // 'HTTP';
-}
-
-
-sub agent {
-	# uncoverable pod (see Deprecations.pod)
-	my ($self) = @_;
-	warnings::warnif deprecated => __PACKAGE__ . "->agent() is deprecated; call ua() instead";
-	return $self->{agent};
-}
-
-
 sub ua { shift->{agent} }
 
 sub uri { shift->{uri_base} }
@@ -158,7 +142,7 @@ Neo4j::Driver::Net::HTTP::LWP - HTTP network adapter for libwww-perl
 
 =head1 VERSION
 
-version 0.45
+version 1.00
 
 =head1 SYNOPSIS
 
@@ -245,10 +229,6 @@ configures it using the given L<Neo4j::Driver>.
 Returns the L<LWP::UserAgent> instance in use.
 Meant to facilitate reuse.
 
-=head1 BUGS
-
-The C<fetch_event()> method has not yet been optimised.
-
 =head1 SEE ALSO
 
 L<Neo4j::Driver::Net>
