@@ -4,7 +4,7 @@ use warnings;
 
 package Neo4j::Driver::Plugin;
 # ABSTRACT: Plug-in interface for Neo4j::Driver
-$Neo4j::Driver::Plugin::VERSION = '0.45'; # TRIAL
+$Neo4j::Driver::Plugin::VERSION = '1.00'; # TRIAL
 
 1;
 
@@ -20,25 +20,7 @@ Neo4j::Driver::Plugin - Plug-in interface for Neo4j::Driver
 
 =head1 VERSION
 
-version 0.45
-
-=head1 DESCRIPTION
-
-This is the abstract base class for L<Neo4j::Driver> plug-ins.
-All plug-ins must inherit from L<Neo4j::Driver::Plugin>
-(or perform the role another way). For a description of the
-required behaviour for plug-ins, see L</"METHODS"> below.
-
-Plug-ins can be used to extend and customise L<Neo4j::Driver>
-to a significant degree. Upon being loaded, a plug-in will be
-asked to register event handlers with the driver. Handlers
-are references to custom subroutines defined by the plug-in.
-They will be invoked when the event they were registered for
-is triggered. Events triggered by the driver are specified in
-L</"EVENTS"> below. Plug-ins can also define custom events.
-
-I<The plug-in interface as described in this document is available
-since version 0.34.>
+version 1.00
 
 =head1 SYNPOSIS
 
@@ -71,19 +53,36 @@ since version 0.34.>
 =head1 WARNING: EXPERIMENTAL
 
 The design of the plug-in API is not finalised.
-You should probably let me know if you already are writing
-plug-ins, so that I can try to accommodate your use case
-and give you advance notice of changes.
 
 B<The entire plug-in API is currently experimental.>
 
-The driver's C<plugin()> method is
-L<experimental|Neo4j::Driver/"Plug-in modules"> as well.
+As such, it is subject to unannounced modification or removal
+in future versions. Expect your code to break if you depend
+upon this feature.
 
-I'm grateful for any feedback you I<(yes, you!)> might have on
-this driver's plug-in API. Please open a GitHub issue or get in
-touch via email (make sure you mention Neo4j in the subject to
-beat the spam filters).
+If you feel the plug-in API is useful, please let me know
+(for example, in a GitHub issue). Your feedback will inform
+decisions on future changes to the API. I'd also be happy
+to consider declaring parts of the API stable if I knew
+somebody other than myself was using it.
+
+=head1 DESCRIPTION
+
+This is the abstract base class for L<Neo4j::Driver> plug-ins.
+All plug-ins must inherit from L<Neo4j::Driver::Plugin>
+(or perform the role another way). For a description of the
+required behaviour for plug-ins, see L</"METHODS"> below.
+
+Plug-ins can be used to extend and customise L<Neo4j::Driver>
+to a significant degree. Upon being loaded, a plug-in will be
+asked to register event handlers with the driver. Handlers
+are references to custom subroutines defined by the plug-in.
+They will be invoked when the event they were registered for
+is triggered. Events triggered by the driver are specified in
+L</"EVENTS"> below. Plug-ins can also define custom events.
+
+I<The plug-in interface as described in this document is available
+since version 0.34.>
 
 =head1 EVENTS
 
@@ -218,9 +217,6 @@ to provide additional arguments. Because subroutine signatures
 perform strict checks of the number of arguments, they are not
 recommended for event handlers.
 
-This method used to be named C<add_event_handler()>.
-There is a compatibility alias, but its use is deprecated.
-
 =item trigger
 
  $events->trigger( 'event_name', @parameters );
@@ -247,9 +243,6 @@ Calling this method in list context is discouraged, because doing
 so might be treated specially by a future version of the driver.
 Use C<scalar> to be safe.
 
-This method used to be named C<trigger_event()>.
-There is a compatibility alias, but its use is deprecated.
-
 =back
 
 =head1 EXTENDING THE DRIVER
@@ -291,7 +284,7 @@ into the Neo4j::Driver:: namespace.
 
 =head2 Network adapter API for Bolt
 
-At this time (2022), there is only one known implementation of the
+At this time (2024), there is only one known implementation of the
 Bolt protocol for Perl: L<Neo4j::Bolt>, created by Mark A. Jensen.
 
 For this reason, an abstraction API for Bolt network adapters has
@@ -510,19 +503,12 @@ At least scheme, host, and port must be included.
 
 =head2 Result handler API
 
-Making a Neo4j result handler API available to plug-ins will
-require significant internal changes to the driver. These
-are currently being postponed, at least until most of the
-L<deprecated functionality|Neo4j::Driver::Deprecations> has
-been removed from the driver's code base.
-
-Even then, the result handler API may have low priority.
-However, new plug-in events are anticipated in a future version
-that should enable clients to achieve some of the same goals.
-
-In the meantime, the result handler API remains not formally
+The result handler API remains not formally
 specified. It is an internal API that is evolving and may be
 subject to unannounced change; see L</"USE OF INTERNAL APIS">.
+Specifying a Neo4j result handler API for the use of plug-ins
+and/or adding new plug-in events that may enable clients to
+achieve some of the same goals has low priority.
 
 A few notes on the result handler API that may or may not be
 accurate by the time you read this:
@@ -570,8 +556,7 @@ your code is used in production.
 
 If you have difficulties achieving your goals without the use of
 driver internals or private APIs, you are most welcome to file a
-GitHub issue about that (or write to my CPAN email address with
-your concerns).
+GitHub issue about that.
 
 I can't I<promise> that I'll be able to accommodate your use case,
 but I am going to try.
