@@ -5,9 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Result;
 # ABSTRACT: Result of running a Cypher statement (a stream of records)
-$Neo4j::Driver::Result::VERSION = '0.45'; # TRIAL
-
-use parent 'Neo4j::Driver::StatementResult';
+$Neo4j::Driver::Result::VERSION = '1.00'; # TRIAL
 
 use Carp qw(croak);
 
@@ -152,24 +150,6 @@ sub has_next {
 }
 
 
-sub attached {
-	# uncoverable pod (see Deprecations.pod)
-	my ($self) = @_;
-	
-	warnings::warnif deprecated => __PACKAGE__ . "->attached is deprecated";
-	return $self->{attached};
-}
-
-
-sub detach {
-	# uncoverable pod (see Deprecations.pod)
-	my ($self) = @_;
-	
-	warnings::warnif deprecated => __PACKAGE__ . "->detach is deprecated";
-	return $self->_fill_buffer;
-}
-
-
 sub consume {
 	my ($self) = @_;
 	
@@ -189,16 +169,6 @@ sub summary {
 }
 
 
-sub stats {
-	# uncoverable pod (see Deprecations.pod)
-	my ($self) = @_;
-	warnings::warnif deprecated => __PACKAGE__ . "->stats is deprecated; use summary instead";
-	
-	$self->_fill_buffer;
-	return $self->{result}->{stats} ? $self->summary->counters : {};
-}
-
-
 sub _bool_values {
 	no if $^V ge v5.36, 'warnings', 'experimental::builtin';
 	if ( $^V ge v5.36 && ! $ENV{NO_NEO4J_CORE_BOOLS} ) {
@@ -225,27 +195,35 @@ Neo4j::Driver::Result - Result of running a Cypher statement (a stream of record
 
 =head1 VERSION
 
-version 0.45
+version 1.00
 
 =head1 SYNOPSIS
 
- use Neo4j::Driver;
- $session = Neo4j::Driver->new->basic_auth(...)->session;
+ $result = $session->run( ... );
  
- # stream result records
- $result = $session->run('MATCH (a:Actor) RETURN a.name, a.born');
+ # Stream result records
  while ( $record = $result->fetch ) {
    ...
  }
  
- # list result records
- $result = $session->run('MATCH (m:Movie) RETURN m.name, m.year');
- $record_count = $result->size;
+ # List result records
  @records = $result->list;
+ $records = $result->list;  # array ref
+ $record_count = $result->size;
  
- # shortcut for results with a single record only
- $query = 'MATCH (m:Movie) WHERE id(m) = {id} RETURN m.name';
- $name = $session->run($query, id => 12)->single->get('m.name');
+ # Shortcut for results with a single record only
+ $record = $result->single;
+ 
+ @field_keys = $result->keys;
+ $summary = $result->consume;
+ 
+ # For error checking, call any method on the result to ensure
+ # the statement has executed before leaving the try block
+ try {
+   $result = $transaction->run( ... );
+   $result->has_next;
+ }
+ catch ($e) { ... }
 
 =head1 DESCRIPTION
 
@@ -260,16 +238,19 @@ buffered locally in the driver. Once I<all> data on the result stream
 has been retrieved from the server and buffered locally, the stream
 becomes B<detached.>
 
-Results received over HTTP always contain the complete list of
-records, which is kept buffered in the driver. HTTP result streams
-are thus immediately detached and valid indefinitely.
-
-Result streams received on Bolt are valid until the next statement
+Result streams are valid until the next statement
 is run on the same session or (if the result was retrieved within
 an explicit transaction) until the transaction is closed, whichever
 comes first. When a result stream has become invalid I<before> it
 was detached, calling any methods in this class may fail.
 
+Some result handlers may automatically detach a result stream
+immediately when the result is made available by the server.
+Such result streams are valid indefinitely.
+In driver S<version 0.xx,> this happens for all HTTP results.
+This behaviour is subject to change in future versions and
+shouldn't be relied upon.
+
 To obtain a query result, call L<Neo4j::Driver::Transaction/"run">.
 
 Until version 0.18, this module was named C<StatementResult>.
@@ -318,7 +299,8 @@ detach the result, but will never exhaust it.
 
  @keys = $result->keys;
 
-Retrieve the column names of the records this result contains.
+Retrieve the column names (field keys) of the records this result
+contains. In scalar context, return the number of columns.
 
 =head2 list
 
@@ -380,22 +362,6 @@ way.
  $record = $transaction->run('...')->single;
  $result_summary = $record->summary;
 
-=head1 EXPERIMENTAL FEATURES
-
-L<Neo4j::Driver::Result> implements the following
-experimental features. These are subject to unannounced modification
-or removal in future versions. Expect your code to break if you
-depend upon these features.
-
-=head2 Calling in scalar context
-
- $count = $result->keys;
-
-The C<keys()> method returns the number of columns if called in scalar
-context.
-
-Until version 0.25, it returned an array reference instead.
-
 =head1 SEE ALSO
 
 =over
@@ -406,10 +372,10 @@ Until version 0.25, it returned an array reference instead.
 L<Neo4j::Driver::B<ResultSummary>>
 
 =item * Equivalent documentation for the official Neo4j drivers:
-L<Result (Java)|https://neo4j.com/docs/api/java-driver/5.2/org.neo4j.driver/org/neo4j/driver/Result.html>,
-L<Result (Python)|https://neo4j.com/docs/api/python-driver/5.2/api.html#result>,
-L<Result (JavaScript)|https://neo4j.com/docs/api/javascript-driver/5.2/class/lib6/result.js~Result.html>,
-L<IResult (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.2/html/f1ac31ec-c6dd-798b-b5d6-3ca0794d7502.htm>
+L<Result (Java)|https://neo4j.com/docs/api/java-driver/5.26/org.neo4j.driver/org/neo4j/driver/Result.html>,
+L<Result (Python)|https://neo4j.com/docs/api/python-driver/5.26/api.html#result>,
+L<Result (JavaScript)|https://neo4j.com/docs/api/javascript-driver/5.26/class/lib6/result.js~Result.html>,
+L<IResult (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.13/html/f1ac31ec-c6dd-798b-b5d6-3ca0794d7502.htm>
 
 =back
 
