@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Result::Jolt;
 # ABSTRACT: Jolt result handler
-$Neo4j::Driver::Result::Jolt::VERSION = '0.45'; # TRIAL
+$Neo4j::Driver::Result::Jolt::VERSION = '1.00'; # TRIAL
 
 # This package is not part of the public Neo4j::Driver API.
 
@@ -199,6 +199,7 @@ sub _init_record {
 	
 	$record->{column_keys} = $self->{columns};
 	$self->_deep_bless( $record->{row} );
+	$record->{meta} = 'The Neo4j::Driver::Record->{meta} feature was removed';
 	return bless $record, 'Neo4j::Driver::Record';
 }
 
@@ -309,8 +310,8 @@ sub _deep_bless {
 	if ($sigil eq '#') {  # Bytes
 		$value =~ tr/ //d;  # spaces were allowed in the Jolt draft, but aren't actually implemented in Neo4j 4.2's jolt.JoltModule
 		$value = pack 'H*', $value;  # see neo4j#12660
-		utf8::downgrade($value);  # UTF8 flag should be off already, but let's make sure
-		return $value;
+		require Neo4j::Driver::Type::Bytes;
+		return bless \$value, 'Neo4j::Driver::Type::Bytes';
 	}
 	
 	die "Assertion failed: unexpected sigil: " . $sigil;
