@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::ResultSummary;
 # ABSTRACT: Details about the result of running a statement
-$Neo4j::Driver::ResultSummary::VERSION = '0.45'; # TRIAL
+$Neo4j::Driver::ResultSummary::VERSION = '1.00'; # TRIAL
 
 use Carp qw(croak);
 
@@ -90,20 +90,18 @@ Neo4j::Driver::ResultSummary - Details about the result of running a statement
 
 =head1 VERSION
 
-version 0.45
+version 1.00
 
 =head1 SYNOPSIS
 
- use Neo4j::Driver;
- $driver = Neo4j::Driver->new->basic_auth(...);
- $result = $driver->session->run('MATCH (a)-[:KNOWS]-(b) RETURN a, b');
- 
- $summary = $result->summary;
+ $summary = $session->execute_write( sub ($transaction) {
+   return $transaction->run( ... )->consume;
+ });
  
  # SummaryCounters
  $counters = $summary->counters;
  
- # query information
+ # Query information
  $query  = $summary->statement->{text};
  $params = $summary->statement->{parameters};
  $plan   = $summary->plan;
@@ -111,7 +109,7 @@ version 0.45
  
  # ServerInfo
  $address = $summary->server->address;
- $version = $summary->server->version;
+ $version = $summary->server->agent;
 
 =head1 DESCRIPTION
 
@@ -120,7 +118,7 @@ used to investigate details about the result, like the Neo4j server
 version, how many and which kinds of updates have been executed, and
 query plan information if available.
 
-To obtain a result summary, call L<Neo4j::Driver::Result/"summary">.
+To obtain a result summary, call L<Neo4j::Driver::Result/"consume">.
 
 =head1 METHODS
 
@@ -144,6 +142,7 @@ statement. Notifications can be warnings about problematic statements
 or other valuable information that can be presented in a client.
 Unlike failures or errors, notifications do not affect the execution
 of a statement.
+In scalar context, return the number of notifications.
 
 This driver only supports notifications over HTTP.
 
@@ -172,23 +171,6 @@ the host, port, protocol and Neo4j version.
 
 The statement and parameters this summary is for.
 
-=head1 EXPERIMENTAL FEATURES
-
-L<Neo4j::Driver::ResultSummary> implements the following experimental
-features. These are subject to unannounced modification or removal
-in future versions. Expect your code to break if you depend upon
-these features.
-
-=head2 Calling in scalar context
-
- $count = $summary->notifications;
-
-The C<notifications()> method returns the number of notifications
-if called in scalar context.
-
-Until version 0.25, it returned an array reference instead,
-or C<undef> if there were no notifications.
-
 =head1 SEE ALSO
 
 =over
@@ -199,9 +181,9 @@ or C<undef> if there were no notifications.
 L<Neo4j::Driver::B<SummaryCounters>>
 
 =item * Equivalent documentation for the official Neo4j drivers:
-L<ResultSummary (Java)|https://neo4j.com/docs/api/java-driver/5.2/org.neo4j.driver/org/neo4j/driver/summary/ResultSummary.html>,
-L<ResultSummary (JavaScript)|https://neo4j.com/docs/api/javascript-driver/5.2/class/lib6/result-summary.js~ResultSummary.html>,
-L<IResultSummary (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.2/html/17958e2b-d923-ab62-bb96-697556493c2e.htm>
+L<ResultSummary (Java)|https://neo4j.com/docs/api/java-driver/5.26/org.neo4j.driver/org/neo4j/driver/summary/ResultSummary.html>,
+L<ResultSummary (JavaScript)|https://neo4j.com/docs/api/javascript-driver/5.26/class/lib6/result-summary.js~ResultSummary.html>,
+L<IResultSummary (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.26/api/Neo4j.Driver.IResultSummary.html>
 
 =back
 
