@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::ServerInfo;
 # ABSTRACT: Provides Neo4j server address and version
-$Neo4j::Driver::ServerInfo::VERSION = '0.45'; # TRIAL
+$Neo4j::Driver::ServerInfo::VERSION = '1.00'; # TRIAL
 
 use Carp qw(croak);
 our @CARP_NOT = qw(Neo4j::Driver::Session);
@@ -33,16 +33,6 @@ sub protocol_version {
 }
 
 
-sub protocol {
-	# uncoverable pod (see Deprecations.pod)
-	my ($self) = @_;
-	warnings::warnif deprecated => __PACKAGE__ . "->protocol() is deprecated; use protocol_version() instead";
-	my $bolt_version = $self->{protocol};
-	return "Bolt/$bolt_version" if $bolt_version;
-	return defined $bolt_version ? "Bolt" : "HTTP";
-}
-
-
 # discover default database on Neo4j >= 4 using the given driver config
 sub _default_database {
 	my ($self, $driver) = @_;
@@ -76,16 +66,16 @@ Neo4j::Driver::ServerInfo - Provides Neo4j server address and version
 
 =head1 VERSION
 
-version 0.45
+version 1.00
 
 =head1 SYNOPSIS
 
- use Neo4j::Driver;
- $session = Neo4j::Driver->new->basic_auth(...)->session;
+ $server_info = $session->server;
+ $server_info = $result_summary->server;
  
- $host_port = $session->server->address;
- $version_string = $session->server->version;
- say "Contacting $version_string at $host_port.";
+ $host_port     = $server_info->address;
+ $neo4j_version = $server_info->agent;
+ $bolt_version  = $server_info->protocol_version;
 
 =head1 DESCRIPTION
 
@@ -146,9 +136,9 @@ This method may be deprecated and removed in future.
 L<Neo4j::Driver::B<ResultSummary>>
 
 =item * Equivalent documentation for the official Neo4j drivers:
-L<ServerInfo (Java)|https://neo4j.com/docs/api/java-driver/5.2/org.neo4j.driver/org/neo4j/driver/summary/ServerInfo.html>,
-L<IServerInfo (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.2/html/24780fbc-1b81-92a8-97f6-a484475e18dc.htm>,
-L<ServerInfo (Python)|https://neo4j.com/docs/api/python-driver/5.2/api.html#serverinfo>
+L<ServerInfo (Java)|https://neo4j.com/docs/api/java-driver/5.26/org.neo4j.driver/org/neo4j/driver/summary/ServerInfo.html>,
+L<IServerInfo (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.26/api/Neo4j.Driver.IServerInfo.html>,
+L<ServerInfo (Python)|https://neo4j.com/docs/api/python-driver/5.26/api.html#serverinfo>
 
 =back
 
