@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Session;
 # ABSTRACT: Context of work for database interactions
-$Neo4j::Driver::Session::VERSION = '0.45'; # TRIAL
+$Neo4j::Driver::Session::VERSION = '1.00'; # TRIAL
 
 use Carp qw(croak);
 our @CARP_NOT = qw(
@@ -109,6 +109,11 @@ sub _execute {
 			}
 		};
 	} until ($success);
+	
+	$r = $r[0] if $wantarray;
+	if (defined $wantarray && blessed $r && $r->isa('Neo4j::Driver::Result')) {
+		warnings::warnif closure => "Result object may not be valid outside the transaction function";
+	}
 	return $wantarray ? @r : $r;
 }
 
@@ -127,12 +132,6 @@ sub execute_write {
 }
 
 
-sub close {
-	# uncoverable pod (see Deprecations.pod)
-	warnings::warnif deprecated => __PACKAGE__ . "->close() is deprecated";
-}
-
-
 sub server {
 	my ($self) = @_;
 	
@@ -202,23 +201,22 @@ Neo4j::Driver::Session - Context of work for database interactions
 
 =head1 VERSION
 
-version 0.45
+version 1.00
 
 =head1 SYNOPSIS
 
- use Neo4j::Driver;
- $session = Neo4j::Driver->new->basic_auth(...)->session;
+ $session = Neo4j::Driver->new(...)->session;
  
- # managed transaction function
+ # Managed transaction function
  @records = $session->execute_read( sub ($transaction) {
-   $transaction->run('MATCH (m:Movie) RETURN m')->list;
+   $transaction->run( ... )->list;
  });
  
- # unmanaged explicit transaction
+ # Unmanaged explicit transaction
  $transaction = $session->begin_transaction;
  
- # autocommit transaction
- $result = $session->run('MATCH (m:Movie) RETURN m.name, m.year');
+ # Autocommit transaction
+ $result = $session->run( ... );
 
 =head1 DESCRIPTION
 
@@ -319,10 +317,9 @@ Because of this, the given subroutine needs to be B<idempotent>
 it is executed).
 
 Note that L<Neo4j::Driver::Result> objects may not be valid
-outside of the given subroutine. While the driver currently
-doesn't prevent you from returning such an object from the
-subroutine, the effect of doing so with results retrieved over
-a Bolt connection is unspecified. A simple solution might be
+outside of the given subroutine. If the driver detects that
+you return such an object, it will issue a warning in the
+category C<closure>. A better approach would be
 to return the list of records from the subroutine instead,
 which is always safe to do.
 
@@ -349,31 +346,6 @@ commit the transaction.
 Obtain the L<ServerInfo|Neo4j::Driver::ServerInfo>, consisting of
 the host, port, protocol and Neo4j version.
 
-=head1 EXPERIMENTAL FEATURES
-
-L<Neo4j::Driver::Session> implements the following experimental
-features. These are subject to unannounced modification or removal
-in future versions. Expect your code to break if you depend upon
-these features.
-
-=head2 Concurrent transactions
-
- %config = ( uri => 'http://...', concurrent_tx => 1 );
- $session = Neo4j::Driver->new(\%config)->session;
- $tx1 = $session->begin_transaction;
- $tx2 = $session->begin_transaction;
- $tx3 = $session->run(...);
-
-Since HTTP is a stateless protocol, the Neo4j HTTP API effectively
-allows multiple concurrently open transactions without special
-client-side considerations. This driver exposes this feature to the
-client and will continue to do so, but the interface is not yet
-finalised. See L<Neo4j::Driver/"Concurrent transactions in HTTP sessions">
-for further details.
-
-The Bolt protocol does not support concurrent transactions (sometimes
-known as "nested transactions") within the same session.
-
 =head1 SECURITY CONSIDERATIONS
 
 Both L<Session|Neo4j::Driver::Session> as well as
@@ -397,9 +369,9 @@ L<Neo4j::Driver::B<ServerInfo>>,
 L<Neo4j::Driver::B<Result>>
 
 =item * Equivalent documentation for the official Neo4j drivers:
-L<Session (Java)|https://neo4j.com/docs/api/java-driver/5.2/org.neo4j.driver/org/neo4j/driver/Session.html>,
-L<Session (JavaScript)|https://neo4j.com/docs/api/javascript-driver/5.2/class/lib6/session.js~Session.html>,
-L<ISession (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.2/html/6bcf5d8c-98e7-b521-03e7-210cd6155850.htm>
+L<Session (Java)|https://neo4j.com/docs/api/java-driver/5.26/org.neo4j.driver/org/neo4j/driver/Session.html>,
+L<Session (JavaScript)|https://neo4j.com/docs/api/javascript-driver/5.26/class/lib6/session.js~Session.html>,
+L<ISession (.NET)|https://neo4j.com/docs/api/dotnet-driver/5.13/html/6bcf5d8c-98e7-b521-03e7-210cd6155850.htm>
 
 =back
 
